package com.chelvc.framework.base.config;

import java.util.List;

import com.chelvc.framework.base.context.DefaultSessionFactory;
import com.chelvc.framework.base.context.SessionFactory;
import com.chelvc.framework.base.interceptor.ResponseWrapInterceptor;
import com.chelvc.framework.common.util.ObjectUtils;
import com.google.common.collect.Lists;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.web.method.support.HandlerMethodReturnValueHandler;
import org.springframework.web.servlet.mvc.method.annotation.RequestMappingHandlerAdapter;
import org.springframework.web.servlet.mvc.method.annotation.RequestResponseBodyMethodProcessor;

/**
 * 应用配置
 *
 * @author Woody
 * @date 2024/1/30
 */
@Configuration
public class ApplicationConfigurer {
    @Bean
    @ConditionalOnMissingBean(SessionFactory.class)
    public SessionFactory sessionFactory() {
        return new DefaultSessionFactory();
    }

    @Bean
    @ConditionalOnMissingBean(ResponseWrapInterceptor.class)
    public ResponseWrapInterceptor responseWrapInterceptor(RequestMappingHandlerAdapter adapter) {
        List<HandlerMethodReturnValueHandler> handlers =
                ObjectUtils.ifNull(adapter.getReturnValueHandlers(), Lists::newArrayList, Lists::newArrayList);
        HandlerMethodReturnValueHandler processor = handlers.stream()
                .filter(handler -> handler instanceof RequestResponseBodyMethodProcessor).findAny().orElse(null);
        ResponseWrapInterceptor interceptor = new ResponseWrapInterceptor(processor);
        handlers.add(0, interceptor);
        adapter.setReturnValueHandlers(handlers);
        return interceptor;
    }
}
