package com.chelvc.framework.database.context;

import javax.crypto.Cipher;

import com.chelvc.framework.common.util.AESUtils;
import com.chelvc.framework.common.util.AssertUtils;
import com.chelvc.framework.database.config.DatabaseProperties;
import lombok.NonNull;

/**
 * 数据库数据加解密上下文默认实现
 *
 * @author Woody
 * @date 2024/6/25
 */
public class DefaultDatabaseCryptoContext implements DatabaseCryptoContext {
    private final String key;
    private final String name;
    private final String secret;
    private final DatabaseProperties.Sensitive properties;

    public DefaultDatabaseCryptoContext(@NonNull DatabaseProperties properties) {
        this.properties = properties.getSensitive();
        this.name = AESUtils.ECB_PKCS5PADDING;
        this.secret = this.properties.getSecret();
        this.key = this.secret == null ? null : (this.name + this.secret);
    }

    @Override
    public Cipher getCipher(int mode) {
        String secret = AssertUtils.nonempty(this.secret, () -> "Crypto secret is missing");
        return AESUtils.lookupCipher(this.key, mode, () -> AESUtils.getCipher(this.name, mode, secret));
    }

    @Override
    public boolean isSensitiveMixed() {
        return this.properties.isMixed();
    }

    @Override
    public boolean isSensitiveWritable() {
        return this.properties.isWritable();
    }
}
