package com.chelvc.framework.oauth.config;

import java.util.Collections;
import java.util.List;

import lombok.Data;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.context.annotation.Configuration;

/**
 * OAuth认证配置属性
 *
 * @author Woody
 * @date 2024/1/30
 */
@Data
@Configuration
@ConfigurationProperties("oauth")
public class OAuthProperties {
    /**
     * 令牌密钥
     */
    private String secret;

    /**
     * 是否区分应用范围
     */
    private boolean scoped;

    /**
     * 忽略地址列表
     */
    private List<String> ignores = Collections.emptyList();

    /**
     * Redis配置
     */
    private final Redis redis = new Redis();

    /**
     * Redis配置信息
     */
    @Data
    public static class Redis {
        /**
         * 是否启用基于Redis的令牌校验
         */
        private boolean enabled = true;
    }
}
