package com.chelvc.framework.security.config;

import lombok.Data;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.context.annotation.Configuration;

/**
 * 信息安全配置属性
 *
 * @author Woody
 * @date 2024/1/30
 */
@Data
@Configuration
@ConfigurationProperties("security")
public class SecurityProperties {
    /**
     * 安全密钥
     */
    private String secret;

    /**
     * 请求时长（毫秒）
     */
    private long duration = 60 * 1000;

    /**
     * 密文标记配置
     */
    private final Mark mark = new Mark();

    /**
     * 敏感字段配置
     */
    private final Sensitive sensitive = new Sensitive();

    /**
     * 敏感字段配置，@Sensitive注解
     */
    @Data
    public static class Sensitive {
        /**
         * 是否开启敏感字段加密
         */
        private boolean enabled;
    }

    /**
     * 密文标记信息
     */
    @Data
    public static class Mark {
        /**
         * 是否开启密文标记
         */
        private boolean enabled;

        /**
         * 标记前缀
         */
        private String prefix = "ENC(";

        /**
         * 标记后缀
         */
        private String suffix = ")";
    }
}
