package com.chelvc.framework.upload.support;

import java.io.File;
import java.io.IOException;
import java.io.InputStream;

import com.chelvc.framework.base.util.HttpUtils;
import com.chelvc.framework.common.util.AssertUtils;
import com.chelvc.framework.common.util.FileUtils;
import com.chelvc.framework.common.util.StringUtils;
import com.chelvc.framework.upload.UploadHandler;
import com.chelvc.framework.upload.config.UploadProperties;
import lombok.NonNull;

/**
 * 文件上传默认实现
 *
 * @author Woody
 * @date 2024/1/30
 */
public class DefaultUploadHandler implements UploadHandler {
    private final String path;
    private final String domain;

    public DefaultUploadHandler(@NonNull UploadProperties.Client properties) {
        this.path = AssertUtils.nonempty(properties.getPath(), () -> "Local upload path is missing");
        this.domain = AssertUtils.nonempty(properties.getDomain(), () -> "Local upload access domain is missing");
    }

    @Override
    public String upload(@NonNull File file) throws IOException {
        String suffix = FileUtils.getSuffix(file);
        String filename = StringUtils.uuid() + StringUtils.ifEmpty(suffix, name -> "." + name, StringUtils.EMPTY);
        FileUtils.write(new File(this.path, filename), file);
        return HttpUtils.url(this.domain, filename);
    }

    @Override
    public String upload(@NonNull InputStream stream, String suffix) throws IOException {
        return this.upload(stream, suffix, stream.available());
    }

    @Override
    public String upload(@NonNull InputStream stream, String suffix, long length) throws IOException {
        String filename = StringUtils.uuid() + StringUtils.ifEmpty(suffix, name -> "." + name, StringUtils.EMPTY);
        FileUtils.write(new File(this.path, filename), stream);
        return HttpUtils.url(this.domain, filename);
    }
}
